@@ -3,9 +3,9 @@ package com.sun.tools.javac.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "11.0.20.1+1" },
-            { "jdk", "11.0.20.1" },
-            { "release", "11.0.20.1" },
+            { "full", "11.0.24+8" },
+            { "jdk", "11.0.24" },
+            { "release", "11.0.24" },
         };
     }
 }
